alle
andre
arbeid
av
begge
bort
bra
bruke
da
denne
der
deres
det
din
disse
du
eller
en
ene
eneste
enhver
enn
er
et
folk
for
fordi
forsÛke
fra
fÅ
fÛr
fÛrst
gjorde
gjÛre
god
gÅ
ha
hadde
han
hans
hennes
her
hva
hvem
hver
hvilken
hvis
hvor
hvordan
hvorfor
ikke
inn
innen
kan
kunne
lage
lang
lik
like
makt
mange
med
meg
meget
men
mens
mer
mest
min
mye
mÅ
mÅte
navn
nei
ny
nÅ
nÅr
og
ogsÅ
om
opp
oss
over
part
punkt
pÅ
rett
riktig
samme
sant
si
siden
sist
skulle
slik
slutt
som
start
stille
tid
til
tilbake
tilstand
under
ut
uten
var
ved
verdi
vi
vil
ville
vite
vÅr
vÖre
vÖrt
Å
