/*
 * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __LIBTRACKER_MINER_H__
#define __LIBTRACKER_MINER_H__

#define __LIBTRACKER_MINER_H_INSIDE__

#include <libtracker-miner/tracker-data-provider.h>
#include <libtracker-miner/tracker-decorator.h>
#include <libtracker-miner/tracker-decorator-fs.h>
#include <libtracker-miner/tracker-miner-object.h>
#include <libtracker-miner/tracker-miner-online.h>
#include <libtracker-miner/tracker-miner-fs.h>
#include <libtracker-miner/tracker-miner-enums.h>
#include <libtracker-miner/tracker-miner-enum-types.h>
#include <libtracker-miner/tracker-indexing-tree.h>
#include <libtracker-miner/tracker-miner-proxy.h>

#undef __LIBTRACKER_MINER_H_INSIDE__

#endif /* __LIBTRACKER_MINER_H__ */
