
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */


#ifndef __TRACKER_MINER_ENUM_TYPES_H__
#define __TRACKER_MINER_ENUM_TYPES_H__

#include <glib-object.h>
#include "tracker-miner-enums.h"

G_BEGIN_DECLS

/* enumerations from "tracker-miner-enums.h" */
GType tracker_directory_flags_get_type (void) G_GNUC_CONST;
#define TRACKER_TYPE_DIRECTORY_FLAGS (tracker_directory_flags_get_type ())
GType tracker_filter_type_get_type (void) G_GNUC_CONST;
#define TRACKER_TYPE_FILTER_TYPE (tracker_filter_type_get_type ())
GType tracker_filter_policy_get_type (void) G_GNUC_CONST;
#define TRACKER_TYPE_FILTER_POLICY (tracker_filter_policy_get_type ())
GType tracker_network_type_get_type (void) G_GNUC_CONST;
#define TRACKER_TYPE_NETWORK_TYPE (tracker_network_type_get_type ())
G_END_DECLS

#endif /* __TRACKER_ENUMS_TYPES_H__ */

/* Generated data ends here */

